@@ -1,6 +1,6 @@
 package Outthentic;
 
-our $VERSION = '0.2.2';
+our $VERSION = '0.2.3';
 
 1;
 
@@ -242,7 +242,12 @@ sub generate_asserts {
 
     dsl()->{match_l} = get_prop('match_l');
 
-    dsl()->{output} = run_story_file();
+    eval { dsl()->{output} = run_story_file() };
+
+    if ($@) {
+      $STATUS = 0;
+      die "story run error: $@";
+    }
 
     eval { dsl()->validate($story_check_file) };
 
@@ -255,9 +260,9 @@ sub generate_asserts {
     }
 
 
-    if ($err){
+    if ($err) {
       $STATUS = 0;
-      confess "outthentic::dsl parser error: $err";
+      die "validator error: $err";
     }
 
 }
@@ -278,20 +283,10 @@ sub note {
 
 }
 
+
 END {
 
-
-  unless ($Outthentic::Silent){
-    print "-"x3;
-    print "\n";
-    if ($STATUS){ 
-      print colored(["green"],"STATUS\tSUCCEED\n");
-      exit(0);
-    }else{
-      print colored(["red"],"STATUS\tFAIL\n");
-      exit(1);
-    }
-  }
+  exit(1) unless $STATUS;
 
 }
 
